@@ -44,7 +44,7 @@ for step in range(10):
     table.update("x squared", x ** 2)
 
     # Display the progress bar by wrapping the iterator
-    for _ in table(range(10)):
+    for _ in table(10):
         # You can use weights for aggregated values
         table.update("random average", random.random(), weight=1)
         time.sleep(0.1)
